/*********************************************************************************************************
*
* File                : DS1302.c
* Hardware Environment: 
* Build Environment   : RealView MDK-ARM  Version: 4.20
* Version             : V1.0
* By                  : 
*
*                                  (c) Copyright 2005-2011, WaveShare
*                                       http://www.waveshare.net
*                                          All Rights Reserved
*
*********************************************************************************************************/

#include <stm32f10x.h>
#include "usart.h"
#include "ds1302.h"
#include "systick.h"
#include <stdio.h>

void DS1302_Configuration(void)
{
	GPIO_InitTypeDef GPIO_InitStruct;
	SPI_Configuration();
	printf("SPI is ready!\r\n");

	GPIO_InitStruct.GPIO_Pin = GPIO_Pin_4;
	GPIO_InitStruct.GPIO_Mode = GPIO_Mode_Out_PP;
	GPIO_InitStruct.GPIO_Speed = GPIO_Speed_50MHz;
	
	GPIO_Init(GPIOA,&GPIO_InitStruct);
	
	DS1302_Disable;
}

void DS1302_write(u8 addr,u8 dat)
{
	DS1302_Disable;
	DS1302_Enable;
	SPI1_Send_byte(addr);
	SPI1_Send_byte(dat);
	DS1302_Disable;
}

u8 DS1302_read(u8 addr)
{
	u8 dat=0;
	DS1302_Disable;
	DS1302_Enable;
	SPI1_Send_byte(addr|0x01);
	dat=SPI1_Receive_byte();
	DS1302_Disable;
	return dat;
}

u8 ReadDS1302Ram(u8 addr)
{
	u8	tmp,res;

	tmp = (addr<<1)|0xc0;
	res = DS1302_read(tmp);
	return(res);
}

void WriteDS1302Ram(u8 addr,u8 data)
{
	u8	tmp;

	DS1302_write(DS1302_WRITE,0x00);		
	tmp = (addr<<1)|0xc0;
	DS1302_write(tmp,data);
	DS1302_write(DS1302_WRITE,0x80);		
}

void ReadDS1302Clock(u8 *p)
{
	DS1302_Disable;
	DS1302_Enable;
	SPI1_Send_byte(0xbf);			
	p[5] = SPI1_Receive_byte();	
	p[4] = SPI1_Receive_byte();		
	p[3] = SPI1_Receive_byte();	
	p[2] = SPI1_Receive_byte();		
	p[1] = SPI1_Receive_byte();		
	p[6] = SPI1_Receive_byte();			
	p[0] = SPI1_Receive_byte();		
	SPI1_Receive_byte();		
	DS1302_Disable;
}

void WriteDS1302Clock(u8 *p)
{
	DS1302_write(DS1302_WRITE,0x00);
	DS1302_Disable;		
	DS1302_Enable;
	SPI1_Send_byte(0xbe);				
	SPI1_Send_byte(p[5]);				
	SPI1_Send_byte(p[4]);				
	SPI1_Send_byte(p[3]);				
	SPI1_Send_byte(p[2]);				
	SPI1_Send_byte(p[1]);				
	SPI1_Send_byte(0x01);				
	SPI1_Send_byte(p[0]);				
	SPI1_Send_byte(0x80);			
	DS1302_Disable;
}

void InitDS1302(void)
{
	u8	tmp;
	tmp = ReadDS1302Ram(0);
	if(tmp^0xa5)
//	if(1)
	{
		WriteDS1302Ram(0,0xa5);
		DS1302_write(DS1302_WRITE,0x00);		
    	DS1302_write(DS1302_YEAR,0x14);
    	DS1302_write(DS1302_MONTH,0x09);
		DS1302_write(DS1302_DAY,0x10);
		DS1302_write(DS1302_HOUR,0x17);	
		DS1302_write(DS1302_MINUTE,0x46);		
		DS1302_write(DS1302_SECOND,0x51);	
		DS1302_write(DS1302_WEEK,0x03);		
		DS1302_write(DS1302_POWER,0xc5);

		DS1302_write(CHARGE_UP,0x80);
		DS1302_write(DS1302_WRITE,0x80);		
	}
}


