#include "stm32f10x.h"
#include <stdio.h>
#include "ds1302.h"

#define DS1302_CLK_H()	(GPIOA->BSRR=GPIO_Pin_5)
#define DS1302_CLK_L()	(GPIOA->BRR=GPIO_Pin_5)

#define DS1302_RST_H()	(GPIOA->BSRR=GPIO_Pin_4)
#define DS1302_RST_L()	(GPIOA->BRR=GPIO_Pin_4)

#define DS1302_OUT_H()	(GPIOA->BSRR=GPIO_Pin_7)
#define DS1302_OUT_L()	(GPIOA->BRR=GPIO_Pin_7)
											
#define DS1302_IN_X		(GPIOA->IDR&GPIO_Pin_7)

#define Time_24_Hour	0x00	
#define Time_Start		0x00	

#define DS1302_SECOND	0x80	
#define DS1302_MINUTE	0x82
#define DS1302_HOUR		0x84
#define DS1302_DAY		0x86
#define DS1302_MONTH	0x88
#define DS1302_WEEK		0x8A
#define DS1302_YEAR		0x8C
#define DS1302_WRITE	0x8E
#define DS1302_POWER	0x90
#define CHARGE_UP  		0xa5

static GPIO_InitTypeDef GPIO_InitStructure;

void DS1302_Configuration(void)
{
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);

	GPIO_ResetBits(GPIOA,GPIO_Pin_4|GPIO_Pin_5|GPIO_Pin_7);
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4|GPIO_Pin_7|GPIO_Pin_5;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;	
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;	
	GPIO_Init(GPIOA, &GPIO_InitStructure);
}


static void DelayNOP(u32 count)
{
	for(; count != 0; count--);
}

static void DS1302_OUT(void)
{
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	GPIO_Init(GPIOA, &GPIO_InitStructure);
}

static void DS1302_IN(void)
{
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU;
	GPIO_Init(GPIOA, &GPIO_InitStructure);
}

void DS1302SendByte(u8 byte)
{
	u8	i;
	for(i=0x01;i;i<<=1)
	{
		if(byte&i)	DS1302_OUT_H();
		else	DS1302_OUT_L();
		DS1302_CLK_H();
		DelayNOP(50);		
		DS1302_CLK_L();
	}
}

u8 DS1302ReceiveByte(void)
{
	u8	i,byte=0;

	for(i=0x01;i;i<<=1)
	{
		if(DS1302_IN_X)	byte |= i;
		DS1302_CLK_H();
		DelayNOP(50);		
		DS1302_CLK_L();
	}
	return(byte);
}

void Write1302(u8 addr,u8 data)
{
  	DS1302_OUT();
	DS1302_RST_L();
	DS1302_CLK_L();
	DS1302_RST_H();
	DelayNOP(100);
	DS1302SendByte(addr);
	DS1302SendByte(data);
	DelayNOP(100);
	DS1302_RST_L();
}

u8 Read1302(u8 addr)
{
  	u8 data=0;

  	DS1302_OUT();
	DS1302_RST_L();
	DS1302_CLK_L();
	DS1302_RST_H();
	DelayNOP(100);
	DS1302SendByte(addr|0x01);
	DS1302_IN();
	data = DS1302ReceiveByte();
	DelayNOP(100);
	DS1302_RST_L();
	return(data);
}




u8 ReadDS1302Ram(u8 addr)
{
	u8	tmp,res;

	tmp = (addr<<1)|0xc0;
	res = Read1302(tmp);
	return(res);
}


void WriteDS1302Ram(u8 addr,u8 data)
{
	u8	tmp;

	Write1302(DS1302_WRITE,0x00);		
	tmp = (addr<<1)|0xc0;
	Write1302(tmp,data);
	Write1302(DS1302_WRITE,0x80);		
}



void ReadDS1302Clock(u8 *p)
{
	DS1302_OUT();
	DS1302_RST_L();
	DS1302_CLK_L();
	DS1302_RST_H();
	DelayNOP(100);
	DS1302SendByte(0xbf);			
	DS1302_IN();
	p[5] = DS1302ReceiveByte();	
	p[4] = DS1302ReceiveByte();		
	p[3] = DS1302ReceiveByte();	
	p[2] = DS1302ReceiveByte();		
	p[1] = DS1302ReceiveByte();		
	p[6] = DS1302ReceiveByte();			
	p[0] = DS1302ReceiveByte();		
	DS1302ReceiveByte();		
	DelayNOP(100);
	DS1302_RST_L();
}


void WriteDS1302Clock(u8 *p)
{
	Write1302(DS1302_WRITE,0x00);		
	DS1302_OUT();
	DS1302_RST_L();
	DS1302_CLK_L();
	DS1302_RST_H();
	DelayNOP(100);
	DS1302SendByte(0xbe);				
	DS1302SendByte(p[5]);				
	DS1302SendByte(p[4]);				
	DS1302SendByte(p[3]);				
	DS1302SendByte(p[2]);				
	DS1302SendByte(p[1]);				
	DS1302SendByte(0x01);				
	DS1302SendByte(p[0]);				
	DS1302SendByte(0x80);			
	DelayNOP(100);
	DS1302_RST_L();
}
void InitDS1302(void)
{
	u8	tmp;
	tmp = ReadDS1302Ram(0);
	if(tmp^0xa5)
//	if(1)
	{
		WriteDS1302Ram(0,0xa5);
		Write1302(DS1302_WRITE,0x00);		
    	Write1302(DS1302_YEAR,0x14);
    	Write1302(DS1302_MONTH,0x07);
		Write1302(DS1302_DAY,0x15);
		Write1302(DS1302_HOUR,0x17);	
		Write1302(DS1302_MINUTE,0x58);		
		Write1302(DS1302_SECOND,0x50);	
		Write1302(DS1302_WEEK,0x02);		
		Write1302(DS1302_POWER,0xc5);

		Write1302(CHARGE_UP,0xa5);
		Write1302(DS1302_WRITE,0x80);		
	}
}

/*******************************END FILE*****************************/



